@@ -23,7 +23,8 @@ def execute(query_str: str, should_print: bool = False) -> dict:
 async def execute_async(query_str: str, should_print: bool = False) -> dict:
     start = time.time()
     async with httpx.AsyncClient() as client:
-        j = await client.get(URL, json={"query": query_str}).json()
+        response = await client.post(URL, json={"query": query_str})
+        j = response.json()
     print(
         f'took: {(time.time() - start) * 1000}, took internal: {int(j["extensions"]["tracing"]["duration"]) / (10 ** 6)}'
     )
