@@ -72,7 +72,7 @@ from .dgraph_model import DGraphModel
 
 
 def parse_filter(filter: DGraphModel) -> str:
-    print(f"{filter=}")
+    # print(f"{filter=}")
     return filter.to_gql_str()
 
 
@@ -116,6 +116,7 @@ class Params(BaseModel):
 
 NodeModel = T.TypeVar("NodeModel", bound="Node")
 ResolverType = T.TypeVar("ResolverType", bound="Resolver")
+ResolverTempType = T.TypeVar("ResolverTempType", bound="Resolver")
 
 
 class Node(BaseModel):
@@ -134,7 +135,7 @@ class Node(BaseModel):
         d = {}
         subs = Node.__subclasses__()
         for sub in subs:
-            typename = sub.GQL.typename
+            typename = sub.Dgraph.typename
             if typename in d:
                 raise GQLException(
                     f"Two Nodes share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
@@ -148,7 +149,7 @@ class Node(BaseModel):
         return r
 
     def get_root_resolver(self) -> T.Type[Resolver]:
-        return Resolver.resolvers_by_typename()[self.GQL.typename]
+        return Resolver.resolvers_by_typename()[self.Dgraph.typename]
 
     @staticmethod
     def should_use_new_resolver(
@@ -183,11 +184,14 @@ class Node(BaseModel):
     def resolve(
         self,
         name: str,
-        resolver: Resolver,
+        resolver: T.Optional[ResolverTempType],
         refresh: bool = False,
         strict: bool = False,
         use_stale: bool = False,
     ) -> T.Optional[T.Union[NodeModel, T.List[NodeModel]]]:
+        root_resolver = self.get_root_resolver()()
+        if not resolver:
+            resolver = root_resolver.edges.__fields__[name].type_()
         if refresh:
             self.cache.remove(name)
         # see if the resolvers do not match
@@ -202,30 +206,19 @@ class Node(BaseModel):
                 )
                 self.cache.remove(name)
         if not self.cache.exists(name):
-            root_resolver = self.get_root_resolver()
-            edge_params = self.GQL.Edges.parse_obj({name: resolver})
-            obj = root_resolver(edges=edge_params)._get(kwargs_d={"id": self.id})
+            setattr(root_resolver.edges, name, resolver)
+            obj = root_resolver._get(kwargs_d={"id": self.id})
             self.cache.replace(key=name, cache=obj.cache.get(name))
         return self.cache.get_val(name)
 
-    class GQL:
+    class Dgraph:
         typename: T.ClassVar[str]
-
-        class GetParams(Params):
-            id: T.Optional[str] = None  # TODO this should be no None right?
-
-        class QueryParams(Params):
-            pass
-
-        class Edges(BaseModel):
-            pass
-
-        resolver: T.Type[ResolverType]
+        resolver: T.ClassVar[T.Type[ResolverType]]
 
     @classmethod
     @property
     def resolver(cls) -> ResolverType:
-        return cls.GQL.resolver()
+        return cls.Dgraph.resolver()
 
 
 from .resolver import Resolver
