@@ -9,32 +9,18 @@ from .node import Node, Params
 
 
 NodeType = T.TypeVar("NodeType", bound=Node)
-ResolverType = T.TypeVar("ResolverType")
-
 
 GetParamsType = T.TypeVar("GetParamsType", bound=Params)
 QueryParamsType = T.TypeVar("QueryParamsType", bound=Params)
 EdgesType = T.TypeVar("EdgesType", bound=BaseModel)
 
 
-class Resolver(BaseModel):
-    node: T.Type[NodeType]
+class Resolver(BaseModel, T.Generic[NodeType]):
+    node: T.ClassVar[T.Type[NodeType]]
 
-    edges: EdgesType
     get_params: GetParamsType
     query_params: QueryParamsType
-
-    @classmethod
-    def from_node(
-        cls: T.Type[ResolverType], node_cls: T.Type[NodeType]
-    ) -> ResolverType:
-        cls(
-            node=node_cls,
-            edges=node_cls.GQL.Edges(),
-            get_params=node_cls.GQL.GetParams(),
-            query_params=node_cls.GQL.QueryParams(),
-        )
-        return cls
+    edges: EdgesType
 
     def gql_fields_str(self) -> str:
         """This does not include the top level..."""
@@ -67,11 +53,11 @@ class Resolver(BaseModel):
 
     @classmethod
     def get_query_name(cls) -> str:
-        return f"get{cls.node.GQL.typename}"
+        return f"get{cls.node.Dgraph.typename}"
 
     @classmethod
     def query_query_name(cls) -> str:
-        return f"query{cls.node.GQL.typename}"
+        return f"query{cls.node.Dgraph.typename}"
 
     def make_query_query_str(self) -> str:
         s = f"{{ {self.query_query_name()}{self.params_and_fields()} }}"
@@ -142,7 +128,7 @@ class Resolver(BaseModel):
         d = {}
         subs = Resolver.__subclasses__()
         for sub in subs:
-            typename = sub.node.GQL.typename
+            typename = sub.node.Dgraph.typename
             if typename in d:
                 raise GQLException(
                     f"Two Resolvers share the typename {typename}: ({sub.__name__}, {d[typename].__name__})"
